@@ -5,7 +5,7 @@ use clap::clap_app;
 use turbojpeg::{Decompressor, Image, PixelFormat};
 
 fn main() -> Result<()> {
-    let args = clap_app!(cjpeg =>
+    let args = clap_app!(djpeg =>
         (about: "Decompresses an image from JPEG")
         (@arg INPUT: <input> "Input JPEG file")
         (@arg OUTPUT: <output> "Output image file")
@@ -24,7 +24,7 @@ fn main() -> Result<()> {
     assert_eq!(strides.1, 3);
     assert_eq!(extents.0, 3);
 
-    decompressor.decompress_to_slice(&image_jpeg, Image {
+    decompressor.decompress(&image_jpeg, Image {
         pixels: image_flat.as_mut_slice(),
         width: extents.1,
         pitch: strides.2,
