@@ -1,8 +1,10 @@
 //! Rust bindings for TurboJPEG, which provides simple and fast operations for JPEG images:
 //!
-//! - Compression (encoding)
-//! - Decompression (decoding)
-//! - Lossless transformations
+//! - [Compression][compress()]: encode images into JPEG.
+//! - [Decompression][decompress()]: decode JPEGs into pixels.
+//! - [Lossless transformations][transform()]: apply basic geometric transformations (rotate, mirror,
+//! ...) without going through decompression and compression, so that the image does not lose
+//! quality.
 //!
 //! # Integration with image-rs
 //! 
@@ -11,13 +13,17 @@
 //! functions [`decompress_image()`][crate::decompress_image] and
 //! [`compress_image()`][crate::compress_image]:
 //! 
-//! ```rust
-//! // create an `image::RgbImage`
-//! let image: image::RgbImage = ...;
-//! // compress `image` into JPEG with quality 95 and no chrominance subsampling
-//! let jpeg_data = turbojpeg::compress_image(&image, 95, turbojpeg::Subsamp::None)?;
+//! ```
+//! // read JPEG data from file
+//! let jpeg_data = std::fs::read("examples/parrots.jpg")?;
+//!
 //! // decompress `jpeg_data` into an `image::RgbImage`
-//! let image: image::RgbImage = turbojpeg::decompress_image(&jpeg_data);
+//! let image: image::RgbImage = turbojpeg::decompress_image(&jpeg_data)?;
+//!
+//! // compress `image` into JPEG with quality 95 and 2x2 chrominance subsampling
+//! let jpeg_data = turbojpeg::compress_image(&image, 95, turbojpeg::Subsamp::Sub2x2)?;
+//!
+//! # Ok::<(), Box<dyn std::error::Error>>(())
 //! ```
 //! 
 //! This crate supports these specializations of [`image::ImageBuffer`][::image::ImageBuffer]:
@@ -45,6 +51,8 @@
 //! - **Compress** images into JPEG using [`compress()`] or [`Compressor`].
 //! - **Transform** images without recompression using [`transform()`] or [`Transformer`]. The
 //! transformations are described in the [`Transform`] struct.
+//! - **Read header** of JPEG image to get its size without decompression using
+//! [`Decompressor::read_header()`] or [`read_header()`].
 //! 
 //! # The [`OutputBuf`] and [`OwnedBuf`] types
 //!
@@ -86,7 +94,7 @@ mod transform;
 pub use self::buf::{OwnedBuf, OutputBuf};
 pub use self::common::{PixelFormat, Subsamp, Colorspace, Result, Error};
 pub use self::compress::{Compressor, compress, compressed_buf_len};
-pub use self::decompress::{Decompressor, DecompressHeader, decompress};
+pub use self::decompress::{Decompressor, DecompressHeader, decompress, read_header};
 pub use self::image::Image;
 pub use self::transform::{Transformer, Transform, TransformOp, TransformCrop, transform};
 
